@@ -31,8 +31,9 @@ class lines:
 
 	def plot_line(self, X, Y, title, xlabel, ylabel, imgText=None, outpath=None, 
 					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
-					ticker_fontsize=9, ticker_rotate=0,
-					xTextLoc=None, yTextLoc=None, color='blue', marker=',', showImg=True):
+					ticker_fontsize=9, xticker_rotate=0, yticker_rotate=0,
+					xTextLoc=None, yTextLoc=None, color='blue', marker=',', showImg=True, 
+					xtick_locations=None, xtick_labels=None, ytick_locations=None, ytick_labels=None):
 		"""create a default 2D line plot
 		
 		: X: (float) the values for x-axis
@@ -59,7 +60,8 @@ class lines:
 		self.add_plot(X,Y, color, marker)
 
 		plt.tick_params(axis='both', which='both', labelsize=ticker_fontsize)
-		plt.xticks(fontsize=ticker_fontsize, rotation=ticker_rotate)
+		plt.xticks(ticks=xtick_locations, labels=xtick_labels, fontsize=ticker_fontsize, rotation=xticker_rotate)
+		plt.yticks(fontsize=ticker_fontsize, rotation=yticker_rotate, ticks=ytick_locations, labels=ytick_labels )
 
 		self.set_title(title, fontsize=self.title_font)
 		self.set_xlabel(xlabel, fontsize=self.xfont)
